@@ -1,31 +1,41 @@
 ## ----setup, include = FALSE---------------------------------------------------
+library(nhdplusTools)
+
+local <- (Sys.getenv("BUILD_VIGNETTES") == "TRUE")
+if(local) {
+  cache_path <- file.path(nhdplusTools_data_dir(), "index_v")
+} else {
+  cache_path <- tempdir()
+}
+
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   fig.width=6, 
   fig.height=4,
-  eval=nzchar(Sys.getenv("BUILD_VIGNETTES")),
-  cache=TRUE,
-  cache.path=(rappdirs::user_cache_dir("nhdplusTools"))
+  eval=local,
+  cache=local,
+  cache.path=(cache_path)
 )
+
 oldoption <- options(scipen = 9999,
                      "rgdal_show_exportToProj4_warnings"="none")
 
 ## ----nhdplus_path_setup, echo=FALSE, include=FALSE----------------------------
 library(dplyr, warn.conflicts = FALSE)
 
-temp_dir <- tempdir()
-dir.create(temp_dir)
+work_dir <- file.path(nhdplusTools_data_dir(), "index_vignette")
+dir.create(work_dir, recursive = TRUE)
 
 source(system.file("extdata/sample_data.R", package = "nhdplusTools"))
 
 file.copy(sample_data,
-          file.path(temp_dir, "natseamless.gpkg"))
+          file.path(work_dir, "natseamless.gpkg"))
 
 ## ----nhdplus_path, echo=TRUE--------------------------------------------------
 library(nhdplusTools)
 
-nhdplus_path(file.path(temp_dir, "natseamless.gpkg"))
+nhdplus_path(file.path(work_dir, "natseamless.gpkg"))
 
 flowlines <- sf::read_sf(nhdplus_path(), "NHDFlowline_Network")
 gages <- sf::read_sf(nhdplus_path(), "Gage")
@@ -155,5 +165,7 @@ dplyr::select(sf::st_drop_geometry(indexed_gages), near_wb_COMID, near_wb_dist,
 
 ## ----teardown, include=FALSE--------------------------------------------------
 options(oldoption)
-unlink(rappdirs::user_cache_dir("nhdplusTools"), recursive = TRUE)
+if(Sys.getenv("BUILD_VIGNETTES") != "TRUE") {
+  unlink(work_dir, recursive = TRUE)
+}
 
