@@ -16,6 +16,19 @@ test_that("nhdplus_data path sets and gets right", {
   nhdplus_path("../NHDPlusV21_National_Seamless.gdb")
 })
 
+test_that("nhdplusTools_data_path works", {
+  check <- tools::R_user_dir("usgs_r/nhdplusTools")
+
+  expect_equal(nhdplusTools_data_dir(),
+               check)
+
+  expect_equal(nhdplusTools_data_dir("test"),
+               "test")
+
+  expect_equal(nhdplusTools_data_dir(check),
+               check)
+})
+
 context("discover nhdplus id")
 
 test_that("discover nhdplus id errors", {
